#!/usr/bin/env bash

SP_ENCODING=utf-8

case $TKMAN_LANG in
    ja|en)
	MANXML_EOCNDING=utf-8
	;;
    ja_euc)
	MANXML_EOCNDING=euc-jp
	;;
    *)
	echo "Error: set TKMAN_LANG to either one of ja, en, ja_euc."
	exit 1
	;;
esac


if [ -e mxml ]; then
    rm -rf mxml
fi
mkdir mxml

if [ -e man ]; then
    rm -rf man
fi
mkdir -p man/man2

# 'FULLWIDTH HYPHEN-MINUS' (U+FF0D) is included in tkernelds_inf.xml
cp -f src/tkernelds_inf.xml _tmp
sed -e 's/－/ - /' < _tmp > src/tkernelds_inf.xml
rm -f _tmp

cat > mxml/join.xsl <<EOL
<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output 
      omit-xml-declaration="no" 
      encoding="utf-8" 
      method="xml" 
      version="1.0" 
      doctype-public="-//OASIS//DTD DocBook XML V4.5//EN"
      doctype-system="http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
      indent="yes" /> 
  <xsl:template match="/">
    <reference>
EOL
for i in src/tkernel??_*.xml; do
    echo "      <xsl:copy-of select=\"document('../$i')/reference/refentry\" />" >> mxml/join.xsl
done
cat >> mxml/join.xsl <<EOL
    </reference>
  </xsl:template>
</xsl:stylesheet>
EOL

xsltproc --encoding utf-8 --output mxml/tkernel_ref.xml mxml/join.xsl src/tkernel_main.xml
db2x_xsltproc -s man mxml/tkernel_ref.xml -o mxml/tkernel_ref.mxml
env LANG=ja_JP.UTF-8 db2x_manxml --list-files --encoding=$MANXML_ENCODING --output-dir=man/man2 mxml/tkernel_ref.mxml
#env LANG=en_US db2x_manxml --list-files --encoding=us-ascii --output-dir=man/man2 mxml/tkernel_ref.mxml

for i in man/man2/*.2; do
    # dirty hack needed to divide these two
    # \*(T>\kx
    # .if (\nx>(\n(.l/2)) .nr x (\n(.l/5)
    cp -f $i _tmp
    sed -e 's/\(\\\*(T>\\kx\)\(.if.*\)$/\1\n\2/' < _tmp > $i
    gzip $i
    rm -f $i _tmp
done
